GeodeticStateTyped

Struct GeodeticStateTyped 

pub struct GeodeticStateTyped {
    pub latitude: Quantity<dyn Dimension<J = Z0, Kind = dyn AngleKind, I = Z0, L = Z0, N = Z0, T = Z0, Th = Z0, M = Z0>, dyn Units<f64, time = second, amount_of_substance = mole, length = meter, luminous_intensity = candela, mass = kilogram, thermodynamic_temperature = kelvin, electric_current = ampere>, f64>,
    pub longitude: Quantity<dyn Dimension<J = Z0, Kind = dyn AngleKind, I = Z0, L = Z0, N = Z0, T = Z0, Th = Z0, M = Z0>, dyn Units<f64, time = second, amount_of_substance = mole, length = meter, luminous_intensity = candela, mass = kilogram, thermodynamic_temperature = kelvin, electric_current = ampere>, f64>,
    pub altitude: Quantity<dyn Dimension<J = Z0, Kind = dyn Kind, I = Z0, L = PInt<UInt<UTerm, B1>>, N = Z0, T = Z0, Th = Z0, M = Z0>, dyn Units<f64, time = second, amount_of_substance = mole, length = meter, luminous_intensity = candela, mass = kilogram, thermodynamic_temperature = kelvin, electric_current = ampere>, f64>,
}
Typed geodetic coordinates on a reference ellipsoid.

Companion to GeodeticState carrying uom dimensioned scalars so signatures expressed with this type are unit-safe.

The polar-singularity behavior is identical to GeodeticState; see Numerical stability at the poles for the caller-side handling.

Fields

latitude: Quantity<dyn Dimension<J = Z0, Kind = dyn AngleKind, I = Z0, L = Z0, N = Z0, T = Z0, Th = Z0, M = Z0>, dyn Units<f64, time = second, amount_of_substance = mole, length = meter, luminous_intensity = candela, mass = kilogram, thermodynamic_temperature = kelvin, electric_current = ampere>, f64>

Geodetic latitude (positive north, range ±π/2).

longitude: Quantity<dyn Dimension<J = Z0, Kind = dyn AngleKind, I = Z0, L = Z0, N = Z0, T = Z0, Th = Z0, M = Z0>, dyn Units<f64, time = second, amount_of_substance = mole, length = meter, luminous_intensity = candela, mass = kilogram, thermodynamic_temperature = kelvin, electric_current = ampere>, f64>

Geodetic longitude (positive east).

Numerically unstable near the poles and assigned 0.0 by convention exactly at the pole; see Numerical stability at the poles for the recommended caller-side handling.

altitude: Quantity<dyn Dimension<J = Z0, Kind = dyn Kind, I = Z0, L = PInt<UInt<UTerm, B1>>, N = Z0, T = Z0, Th = Z0, M = Z0>, dyn Units<f64, time = second, amount_of_substance = mole, length = meter, luminous_intensity = candela, mass = kilogram, thermodynamic_temperature = kelvin, electric_current = ampere>, f64>

Height above the reference ellipsoid.

Implementations

Source

impl GeodeticStateTyped

pub fn from_raw(state: GeodeticState) -> GeodeticStateTyped

Construct a typed state from an untyped GeodeticState assuming the stored components are in radians/meters (their documented base units).

pub fn into_raw(self) -> GeodeticState

Lower a typed state back to the raw GeodeticState (radians/meters).